Crate functionality

Crate functionality 

Modules

prelude

Macros

dyn_fn
dyn_fn_mut
try_scope
Just like the unstable try block, this macro runs the code inside of it, but in a context where returns return from it instead of the top function, acting like a try-catch in a traditional language. This is done by immediately calling a closure.

Structs

RefIter
An iterator adapter for iterating over the contents of a Ref which holds an iterable type.

Traits

IntoExt
This trait exposes another function named into, that can take a generic argument, making it nicer to use in pipe-lines.
Mutate
New
This trait is a generalization of Default::default. The difference is that some types may provide a constructor with no arguments, but not implement Default for some reason. That might be that it’s expensive to create, or mutates some global state, or does some IO, etc.
Pipe
All sized types implement this trait.

Functions

default
A short-hand for calling Default::default(). You may also specify T, but I recommend using T::default() over default::<T>() where you may.