Module prelude

Module prelude 

Re-exports

pub use crate::default;
pub use crate::IntoExt;
pub use crate::Mutate;

Macros

dyn_fn
dyn_fn_mut
try_scope
Just like the unstable try block, this macro runs the code inside of it, but in a context where returns return from it instead of the top function, acting like a try-catch in a traditional language. This is done by immediately calling a closure.

Traits

Pipe
All sized types implement this trait.