IntoExt

Trait IntoExt 

pub trait IntoExt {
    // Provided method
    fn into_<T>(self) -> T
       where Self: Into<T> { ... }
}
This trait exposes another function named into, that can take a generic argument, making it nicer to use in pipe-lines.

Example

use functionality::IntoExt;
let str = "hello";
// You can't do this with `into`!
let string = str.into_::<String>();
// You'd have to use `String::from(str)`

Provided Methods

fn into_<T>(self) -> T
where Self: Into<T>,

Implementors

Source

impl<T> IntoExt for T