Re-exports
Macros
- dyn_fn
- dyn_
fn_ mut - try_
scope - Just like the unstable
tryblock, this macro runs the code inside of it, but in a context where returns return from it instead of the top function, acting like a try-catch in a traditional language. This is done by immediately calling a closure.
Traits
- Pipe
- All sized types implement this trait.